function compexp_downward(inode)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Computes the relation between parent's 2 parameters and those of its
%   two child2en.
% 
% global variables.
%   NODES: tree structure
%   TRANSCoef(1:11,#ofNodes): the child2en-parent coefficient relations,the length
%        of the fundamental period, and the number of Fourier terms for each variable.
%        w1=c1*w1p+c2*w2p+c3*tnew;
%        w2=c4*w1p+c5*w2p+c6*tnew;
%           w1p,w2p are the parent's 2 variables. 
%        TRANSCoef(1:6,inode): store c1-c6. 
%        TRANSCoef(7:8,inode): the interval length of w1 and w2. Outside,
%           the integrand can be considered as 0.
%        TRANSCoef(9-11,inode): the number of Fourier Coefficients
%           for w1, w2 of current node, and t-variable used to decouple
%           parent node.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
global NODES TRANSCoef
if NODES(5,inode)==0, % node is a leaf node, no need to further divide.
    return;
else        
    % the two child nodes.
    child1=NODES(5,inode); child2=NODES(6,inode);
    
    % the values za, zb, zc, zp, zq. The points are ordered as 
    %   [za, zp, zc, zq, zb]
    za=NODES(7,inode);zb=NODES(8,inode);zc=NODES(8,child1);
    % zp value
    if NODES(5,child1)==0, % center of child1ess node.
        zp=(NODES(7,child1)+NODES(8,child1))/2;
    else
        zp=NODES(8,NODES(5,child1));
    end
    % zq value
    if NODES(5,child2)==0, % center of child1ess node.
        zq=(NODES(7,child2)+NODES(8,child2))/2;
    else
        zq=NODES(8,NODES(5,child2));
    end
    
    if NODES(3,inode)==0, % parent node is the root node.
        % For left child. See Mathematica file, ExponentialCase.nb
        %   Basis three case for detailed formulas.
        TRANSCoef(1:2,child1)=zeros([2,1]);
        TRANSCoef(3,child1)=exp(zp-zc)/sqrt(2); % only one t variable.
        TRANSCoef(4:5,child1)=zeros([2,1]);
        TRANSCoef(6,child1)=(zc-za)*exp(zp-zc)/sqrt(2);
        TRANSCoef(7,child1)=abs(TRANSCoef(3,child1))*7; % the interval for w1C.
        TRANSCoef(8,child1)=abs(TRANSCoef(6,child1))*7; % the interval for w2c.
        % t-variable is always from [-7,7], outside can be considered as zero.
        % use the default number of Fourier terms for W1C, W2C, and t. 
        %   TRANSCoef(9:11,child1) unchanged.

        %For right child.
        TRANSCoef(1:2,child2)=zeros([2,1]);
        TRANSCoef(3,child2)=exp(zc-zq)/sqrt(2); % only one t variable.
        TRANSCoef(4:5,child2)=zeros([2,1]);
        TRANSCoef(6,child2)=(zc-zb)*exp(zc-zq)/sqrt(2);
        TRANSCoef(7,child2)=abs(TRANSCoef(3,child2))*7; % the interval for w1c
        TRANSCoef(8,child2)=abs(TRANSCoef(6,child2))*7; % the interval for w2c.
    
    elseif NODES(3,inode)==1, % parent node is a left boundary node.
        %For left child.
        TRANSCoef(1,child1)=cosh(zc-zp); 
        TRANSCoef(2,child1)=sinh(zc-zp)/(za-zb);
        TRANSCoef(3,child1)=sqrt(exp(-zc-zb)*sinh(zb-zc))*exp(zp); % only one t variable.
        TRANSCoef(4,child1)=(za-zc)*sinh(zc-zp);
        TRANSCoef(5,child1)=(za-zc)/(za-zb)*cosh(zc-zp);
        TRANSCoef(6,child1)=(zc-za)*sqrt(exp(-zc-zb)*sinh(zb-zc))*exp(zp);
        TRANSCoef(7,child1)=abs(TRANSCoef(1,child1))*TRANSCoef(7,inode)+...
            abs(TRANSCoef(2,child1))*TRANSCoef(8,inode)+...
            abs(TRANSCoef(3,child1))*7; % the interval for w1C
        TRANSCoef(8,child1)=abs(TRANSCoef(4,child1))*TRANSCoef(7,inode)+...
            abs(TRANSCoef(5,child1))*TRANSCoef(8,inode)+...
            abs(TRANSCoef(6,child1))*7; % the interval for w2C
        % use the default number of Fourier terms for w1c, w2c, and t. 
        %   TRANSCoef(9:10,child1) unchanged.
      
        %For right child.
        TRANSCoef(1,child2)=cosh(zc-zq);
        TRANSCoef(2,child2)=sinh(zc-zq)/(za-zb);
        TRANSCoef(3,child2)=sqrt(-1+coth(zb-zc))*sinh(zb-zq); % only one t variable.
        TRANSCoef(4,child2)=(zc-zb)*sinh(zc-zq);
        TRANSCoef(5,child2)=(zc-zb)/(za-zb)*cosh(zc-zq);
        TRANSCoef(6,child2)=(zc-zb)*sqrt(-1+coth(zb-zc))*cosh(zb-zq);
        TRANSCoef(7,child2)=abs(TRANSCoef(1,child2))*TRANSCoef(7,inode)+...
            abs(TRANSCoef(2,child2))*TRANSCoef(8,inode)+...
            abs(TRANSCoef(3,child2))*7; % the interval for w1C
        TRANSCoef(8,child2)=abs(TRANSCoef(4,child2))*TRANSCoef(7,inode)+...
            abs(TRANSCoef(5,child2))*TRANSCoef(8,inode)+...
            abs(TRANSCoef(6,child2))*7; % the interval for w2C
    
    elseif NODES(3,inode)==2, % parent node is a right boundary node.
        %For left child.
        TRANSCoef(1,child1)=cosh(zc-zp);
        TRANSCoef(2,child1)=sinh(zc-zp)/(za-zb);
        TRANSCoef(3,child1)=sqrt(-1-coth(za-zc))*sinh(-za+zp); % only one t variable.
        TRANSCoef(4,child1)=(za-zc)*sinh(zc-zp);
        TRANSCoef(5,child1)=(za-zc)/(za-zb)*cosh(zc-zp);
        TRANSCoef(6,child1)=(-za+zc)*sqrt(-1-coth(za-zc))*cosh(za-zp);
        TRANSCoef(7,child1)=abs(TRANSCoef(1,child1))*TRANSCoef(7,inode)+...
            abs(TRANSCoef(2,child1))*TRANSCoef(8,inode)+...
            abs(TRANSCoef(3,child1))*7; % the interval for w1C
        TRANSCoef(8,child1)=abs(TRANSCoef(4,child1))*TRANSCoef(7,inode)+...
            abs(TRANSCoef(5,child1))*TRANSCoef(8,inode)+...
            abs(TRANSCoef(6,child1))*7; % the interval for w2C
    
        %For right child.
        TRANSCoef(1,child2)=cosh(zc-zq);
        TRANSCoef(2,child2)=sinh(zc-zq)/(za-zb);
        TRANSCoef(3,child2)=sqrt(exp(zc+za)*sinh(zc-za))*exp(-zq); % only one t variable.
        TRANSCoef(4,child2)=(zc-zb)*sinh(zc-zq);
        TRANSCoef(5,child2)=(zc-zb)/(za-zb)*cosh(zc-zq);
        TRANSCoef(6,child2)=(zc-zb)*sqrt(exp(zc+za)*sinh(zc-za))*exp(-zq);
        TRANSCoef(7,child2)=abs(TRANSCoef(1,child2))*TRANSCoef(7,inode)+...
            abs(TRANSCoef(2,child2))*TRANSCoef(8,inode)+...
            abs(TRANSCoef(3,child2))*7; % the interval for w1C
        TRANSCoef(8,child2)=abs(TRANSCoef(4,child2))*TRANSCoef(7,inode)+...
            abs(TRANSCoef(5,child2))*TRANSCoef(8,inode)+...
            abs(TRANSCoef(6,child2))*7; % the interval for w2C
    
    else % parent node is an interior node.
        %For left child.
        TRANSCoef(1,child1)=cosh(zc-zp);
        TRANSCoef(2,child1)=sinh(zc-zp)/(za-zb);
        TRANSCoef(3,child1)=sqrt(csch(za-zb)*csch(za-zc)*sinh(zb-zc))...
            *sinh(-za+zp);
        TRANSCoef(4,child1)=(za-zc)*sinh(zc-zp);
        TRANSCoef(5,child1)=(za-zc)/(za-zb)*cosh(zc-zp);
        TRANSCoef(6,child1)=(-za+zc)*cosh(za-zp)*sqrt(csch(za-zb)*...
            csch(za-zc)*sinh(zb-zc));
        TRANSCoef(7,child1)=abs(TRANSCoef(1,child1))*TRANSCoef(7,inode)+...
            abs(TRANSCoef(2,child1))*TRANSCoef(8,inode)+...
            abs(TRANSCoef(3,child1))*7; % the interval for w1C
        TRANSCoef(8,child1)=abs(TRANSCoef(4,child1))*TRANSCoef(7,inode)+...
            abs(TRANSCoef(5,child1))*TRANSCoef(8,inode)+...
            abs(TRANSCoef(6,child1))*7; % the interval for w2C
    
        %For right child.
        TRANSCoef(1,child2)=cosh(zc-zq);
        TRANSCoef(2,child2)=sinh(zc-zq)/(za-zb);
        TRANSCoef(3,child2)=sqrt(csch(za-zb)*csch(zb-zc)*sinh(za-zc))...
            *sinh(zb-zq);
        TRANSCoef(4,child2)=(zc-zb)*sinh(zc-zq);
        TRANSCoef(5,child2)=(zc-zb)/(za-zb)*cosh(zc-zq);
        TRANSCoef(6,child2)=(zc-zb)*cosh(zb-zq)*sqrt(csch(za-zb)*...
            csch(zb-zc)*sinh(za-zc));
        TRANSCoef(7,child2)=abs(TRANSCoef(1,child2))*TRANSCoef(7,inode)+...
            abs(TRANSCoef(2,child2))*TRANSCoef(8,inode)+...
            abs(TRANSCoef(3,child2))*7; % the interval for w1C
        TRANSCoef(8,child2)=abs(TRANSCoef(4,child2))*TRANSCoef(7,inode)+...
            abs(TRANSCoef(5,child2))*TRANSCoef(8,inode)+...
            abs(TRANSCoef(6,child2))*7; % the interval for w2C
    end

    % find children's translation coefficients.
    compexp_downward(child1);
    compexp_downward(child2);
end

return
end

